@@ -1,7 +1,9 @@
-from blizz import Relation, Field
-import blizz.check, blizz.apply
 import pandas as pd
 
+import blizz.apply
+import blizz.check
+from blizz import Relation, Field
+
 
 class Iris(Relation):
 
@@ -9,14 +11,15 @@ class Iris(Relation):
     SEPAL_WIDTH = Field("sepal_width", datatype=float)
     PETAL_LENGTH = Field("petal_length", default=0.0)
     PETAL_WIDTH = Field("petal_width", datatype=float)
-    SPECIES = Field("species", datatype=object, key=True)
+    SPECIES = Field("species_renamed", datatype=object, key=True, source_name="species")
 
     @classmethod
     @blizz.check.types
     @blizz.check.fields
     @blizz.check.keys
-    @blizz.apply.defaults
+    @blizz.apply.defaults(fill=PETAL_LENGTH)  # you can use field as arguments, too!
     @blizz.apply.deduplication
+    @blizz.apply.renames  # renames should be applied first
     def load(cls) -> pd.DataFrame:
         return pd.read_csv(
             "https://gist.githubusercontent.com/curran/a08a1080b88344b0c8a7"
